summaryrefslogtreecommitdiff
path: root/riscos/textselection.c
diff options
context:
space:
mode:
Diffstat (limited to 'riscos/textselection.c')
-rw-r--r--riscos/textselection.c21
1 files changed, 12 insertions, 9 deletions
diff --git a/riscos/textselection.c b/riscos/textselection.c
index 2638a36e9..d9d1916ca 100644
--- a/riscos/textselection.c
+++ b/riscos/textselection.c
@@ -61,7 +61,8 @@ static size_t clip_alloc = 0;
static size_t clip_length = 0;
static bool copy_handler(const char *text, size_t length, struct box *box,
- void *handle, const char *whitespace_text);
+ void *handle, const char *whitespace_text,
+ size_t whitespace_length);
static void ro_gui_discard_clipboard_contents(void);
static void ro_gui_dragging_bounced(wimp_message *message);
@@ -189,22 +190,24 @@ void ro_gui_selection_drag_end(struct gui_window *g, wimp_dragged *drag)
* Selection traversal routine for appending text to the current contents
* of the clipboard.
*
* \param text pointer to text being added, or NULL for newline
* \param length length of text to be appended (bytes)
* \param box pointer to text box, or NULL if from textplain
* \param handle unused handle, we don't need one
* \param whitespace_text whitespace to place before text for formatting
* may be NULL
* \return true iff successful and traversal should continue
*/
bool copy_handler(const char *text, size_t length, struct box *box,
- void *handle, const char *whitespace_text)
+ void *handle, const char *whitespace_text,
+ size_t whitespace_length)
{
/* add any whitespace which precedes the text from this box */
if (whitespace_text) {
if (!gui_add_to_clipboard(whitespace_text,
- strlen(whitespace_text), false)) {
+ whitespace_length, false)) {
return false;
}
}
@@ -189,22 +190,24 @@ void ro_gui_selection_drag_end(struct gui_window *g, wimp_dragged *drag)
* of the clipboard.
*
- * \param text pointer to text being added, or NULL for newline
- * \param length length of text to be appended (bytes)
- * \param box pointer to text box, or NULL if from textplain
- * \param handle unused handle, we don't need one
- * \param whitespace_text whitespace to place before text for formatting
- * may be NULL
+ * \param text pointer to text being added, or NULL for newline
+ * \param length length of text to be appended (bytes)
+ * \param box pointer to text box, or NULL if from textplain
+ * \param handle unused handle, we don't need one
+ * \param whitespace_text whitespace to place before text for formatting
+ * may be NULL
+ * \param whitespace_length length of whitespace_text
* \return true iff successful and traversal should continue
*/